@@ -68,13 +68,13 @@ from typing import Any, Callable, Dict, List, NamedTuple, Optional, Set, Tuple,
 import pytest  # nodep
 import sphinx.application
 from bs4 import BeautifulSoup  # type: ignore
+from coincidence.regressions import check_file_output, check_file_regression  # nodep
 from docutils import nodes
 from docutils.parsers.rst import Directive, roles
 from docutils.transforms import Transform
 from domdf_python_tools.doctools import prettify_docstrings
 from domdf_python_tools.paths import PathPlus
 from domdf_python_tools.stringlist import StringList
-from domdf_python_tools.testing import check_file_output, check_file_regression
 from domdf_python_tools.typing import PathLike
 from pygments.lexer import Lexer  # type: ignore  # nodep
 from pytest_regressions.file_regression import FileRegressionFixture  # nodep
